Package: BiocBaseUtils
Title: Utility and internal functions for Bioconductor packages
Version: 1.15.1
Authors@R: c(
  person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu",
    c("aut", "cre"), c(ORCID = "0000-0002-3242-0582")
  ),
  person("Martin", "Morgan", , "martin.morgan@roswellpark.org", "ctb"
  ),
  person("Hervé", "Pagès", , "hpages.on.github@gmail.com", "ctb")
  )
Description: The package coalesces typical helper functions that are
        scattered throughout the Bioconductor ecosystem. It aims to
        reduce code redundancy by formalizing functions often used by
        Bioconductor developers. These functions include operations
        such as replacing slots in an object, selecting observations
        for show methods, labeling function life cycles, and more.
Imports: methods, utils
Depends: R (>= 4.5.0)
Suggests: knitr, rmarkdown, BiocStyle, tinytest
License: Artistic-2.0
Encoding: UTF-8
biocViews: Software, Infrastructure
BugReports: https://www.github.com/Bioconductor/BiocBaseUtils/issues
URL: https://www.github.com/Bioconductor/BiocBaseUtils
Roxygen: list(markdown = TRUE)
VignetteBuilder: knitr
Date: 2026-05-08
Config/roxygen2/version: 8.0.0
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-05-08 19:02:27 UTC
RemoteUrl: https://github.com/bioc/BiocBaseUtils
RemoteRef: HEAD
RemoteSha: 481d51b6ba2e70318654e785b2b4ba84e43ddf48
NeedsCompilation: no
Packaged: 2026-05-08 21:00:14 UTC; root
Author: Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  Martin Morgan [ctb],
  Hervé Pagès [ctb]
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
Built: R 4.6.0; ; 2026-05-08 21:01:53 UTC; unix
