#' BiocBaseUtils: Utility and Internal functions for Bioconductor packages
#'
#' BiocBaseUtils is a package aimed at helping the typical Bioconductor developer
#' formalize often written functions that can be seen scattered throughout the
#' Bioconductor ecosystem. Some of these functions include the ability to
#' replace slots in an object. Other functions work to create a nice show method
#' output by selecting some observations.
#'
#' @aliases NULL
"_PACKAGE"
