% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/askUserYesNo.R
\name{askUserYesNo}
\alias{askUserYesNo}
\title{Ask user for a yes/no response}
\usage{
askUserYesNo(prompt, interactive.only = TRUE)
}
\arguments{
\item{prompt}{\code{character()} Question form prompt to display to the user
without a question mark}

\item{interactive.only}{\code{logical(1)} If \code{TRUE}, the function will only
prompt the user when the R session is interactive. If \code{FALSE}, the
function will always prompt the user.}
}
\value{
TRUE when user replies with 'yes' to prompt, FALSE when 'no'
}
\description{
Ask user for a yes/no response
}
\examples{

askUserYesNo("Do you want to continue")

}
\author{
Martin M.
}
